@@ -58,12 +58,17 @@ Junify_var(head,arg,th)    for variable term
 Junify_nil(arg,th)    for [] check.
 */
 
-:- module(jump,[compile_file/1,compile_file1/1,compile_file/2]).
+:- module(jump,[compile_file/1,compile_file1/1,compile_file/2,option/2,pred_data/3,optimize/1]).
+
+option(_,_).
+pred_data(_,_,_).
+optimize(_).
 
 % main
 compile_file(X) :-
     abolish(option/2),
     assert(option(dummy,-1)),
+    abolish(pred_data/3),
     pass1(X),
     pass2(X),
     pass3(X),
@@ -108,12 +113,12 @@ pass1(X) :-
     reconsult(X,compiler),
     pass1_analize.
 
-pass2(X) :-
+pass2(_) :-
     write(user_output,'phase pass2'),
     nl(user_output),
     pass1_analize.
 
-pass3(X) :-
+pass3(_) :-
     write(user_output,'phase pass3'),
     nl(user_output),
     pass1_analize.
@@ -432,7 +437,7 @@ gen_var_assign(S,E) :-
 
 
 % generate each clause in CPS
-gen_a_pred4([],N).
+gen_a_pred4([],_).
 gen_a_pred4([C|Cs],N) :-
 	n_variable_convert(C,X),
     n_generate_variable(X,V),
@@ -458,14 +463,14 @@ gen_tail_restore_args([A|As],N) :-
     write(',th);'),nl,
     N1 is N+1,
     gen_tail_restore_args(As,N1).
-gen_tail_restore_args([A|As],N) :-
+gen_tail_restore_args([_|As],N) :-
     N1 is N+1,
     gen_tail_restore_args(As,N1).
 
 
 
 % clause sa tail recursive base
-gen_a_pred5((Head :- !),N) :-
+gen_a_pred5((Head :- !),_) :-
     optimize(tail),
     gen_head(Head),
     Head =.. [_|A],
@@ -487,16 +492,16 @@ gen_a_pred5((Head :- Body),N) :-
 gen_a_pred5((Head :- Body),N) :-
     write('save1 = Jget_wp(th);'),nl,
 	gen_head(Head),
-    gen_body(Body,0).
+    gen_body(Body,N).
 
 % predicate with no arity
-gen_a_pred5(P,N) :-
+gen_a_pred5(P,_) :-
 	n_property(P,predicate),
     functor(P,_,0),
     not(n_dynamic_predicate(P)),
     write('return(Jexec_all(rest,Jget_sp(th),th));'),nl.
 
-gen_a_pred5(P,N) :-
+gen_a_pred5(P,_) :-
     n_property(P,predicate),
     functor(P,_,0),
     n_dynamic_predicate(P),
@@ -505,7 +510,7 @@ gen_a_pred5(P,N) :-
     write(')'),nl.
 
 % predicate
-gen_a_pred5(P,N) :-
+gen_a_pred5(P,_) :-
 	n_property(P,predicate),
     P =.. [P1|_],
     not(n_dynamic_predicate(P1)),
@@ -516,9 +521,9 @@ gen_a_pred5(P,N) :-
     write('Junbind(save2,th);'),nl,
     write('Jset_wp(save1,th);'),nl.
 
-gen_a_pred5(P,N) :-
+gen_a_pred5(P,_) :-
     n_property(P,predicate),
-    P =.. [P1|_],
+    P =.. [P1|L],
     n_dynamic_predicate(P),
     write('Jwcons(Jmakepred("'),
     write(P1),
@@ -529,7 +534,7 @@ gen_a_pred5(P,N) :-
 
 
 % user ope
-gen_a_pred5(P,N) :-
+gen_a_pred5(P,_) :-
 	n_property(P,userop),
     write('save1 = Jget_wp(th);'),nl,
 	gen_head(P),
@@ -585,7 +590,7 @@ gen_body(X,_) :-
 
 
 % disjunction
-gen_body(((X1;X2);Y),N) :-
+gen_body(((X;_);Y),N) :-
     write('{dp['),write(N),write(']=Jget_sp(th);'),nl,
     N1 is N+1,
     gen_body(X,N1),
@@ -695,7 +700,7 @@ gen_after_body(X,N) :-
     write('return(NO);}'),nl.
 
 
-gen_body1([],N) :-
+gen_body1([],_) :-
     write('NIL').
 
 gen_body1((D1;D2),N) :-
@@ -731,7 +736,7 @@ gen_body1((X,Xs),N) :-
     gen_body1(Xs,N),
     write(',th)').
 
-gen_body1(X,N) :-
+gen_body1(X,_) :-
 	gen_a_body(X).
 
 /*
@@ -742,7 +747,7 @@ gen_a_body((X;Xs)) :-
 	write('Jwlist3(Jmakeope(";"),'),
 	gen_a_body(X),
     write(','),
-    gen_body1(Xs),
+    gen_body1(Xs,0),
     write(',th)').
 
 
@@ -781,6 +786,65 @@ gen_a_body(X) :-
     write('"),'),
     gen_argument(L),
     write(',th)').
+% is/2 
+gen_a_body(X is Y) :-
+    n_findatom(n_exec_is,builtin,A),
+    write('Jwcons('),
+    write(A),
+    write(','),
+    write('Jwlist2('),
+    eval_form(X),
+    write(','),
+    eval_form(Y),
+    write(',th),th)').
+% </2 
+gen_a_body(X < Y) :-
+    n_findatom(n_exec_smaller,builtin,A),
+    write('Jwcons('),
+    write(A),
+    write(','),
+    write('Jwlist2('),
+    eval_form(X),
+    write(','),
+    eval_form(Y),
+    write(',th),th)').
+
+% >/2 
+gen_a_body(X > Y) :-
+    n_findatom(n_exec_greater,builtin,A),
+    write('Jwcons('),
+    write(A),
+    write(','),
+    write('Jwlist2('),
+    eval_form(X),
+    write(','),
+    eval_form(Y),
+    write(',th),th)').
+
+% =</2 
+gen_a_body(X =< Y) :-
+    n_findatom(n_exec_eqsmaller,builtin,A),
+    write('Jwcons('),
+    write(A),
+    write(','),
+    write('Jwlist2('),
+    eval_form(X),
+    write(','),
+    eval_form(Y),
+    write(',th),th)').
+
+% >=/2 
+gen_a_body(X >= Y) :-
+    n_findatom(n_exec_eqgreater,builtin,A),
+    write('Jwcons('),
+    write(A),
+    write(','),
+    write('Jwlist2('),
+    eval_form(X),
+    write(','),
+    eval_form(Y),
+    write(',th),th)').
+
 % atom builtin e.g. nl fail
 gen_a_body(X) :-
     n_property(X,builtin),
@@ -798,7 +862,7 @@ gen_a_body(X) :-
     write(',th)').
 gen_a_body(X) :-
     n_property(X,operation),
-    gen_body1(X).
+    gen_body1(X,0).
 gen_a_body(X) :-
     n_property(X,compiled),
     X =.. [P|L],
@@ -1298,7 +1362,7 @@ gen_a_argument(X) :-
     write(',th)').
 gen_a_argument(X) :-
     n_property(X,userop),
-    functor(X,Y,0),
+    functor(X,_,0),
     write('Jmakeuser("'),
     write(X),
     write('")').
@@ -1346,7 +1410,7 @@ gen_dynamic(P) :-
     gen_dynamics(P,L),
     write('}'),!.
 
-gen_dynamics(P,[]).
+gen_dynamics(_,[]).
 gen_dynamics(P,[L|Ls]) :-
     gen_dyn(P,L),
     gen_dynamics(P,Ls).
@@ -1586,21 +1650,21 @@ analize1(P,N,C) :-
     not(n_dynamic_predicate(P)),
     length(C,M),
     tail_recursive(C,0,0,0,M,N),
-    P1 =.. [pred_data,P,A1,A2],
+    P1 =.. [pred_data,P,_,_],
     (retract(P1);true),
     asserta(pred_data(P,N,tail)),!.
 analize1(P,N,C) :-
     not(n_dynamic_predicate(P)),
     length(C,M),
     deterministic(C,0,0,0,M),
-    P1 =.. [pred_data,P,A1,A2],
+    P1 =.. [pred_data,P,_,_],
     (retract(P1);true),
     asserta(pred_data(P,N,det)),!.
 analize1(P,N,C) :-
     not(n_dynamic_predicate(P)),
     length(C,M),
     halt_check(C,0,0,M),
-    P1 =.. [pred_data,P,A1,A2],
+    P1 =.. [pred_data,P,_,_],
     (retract(P1);true),
     asserta(pred_data(P,N,halt)),!.
 
@@ -1616,40 +1680,39 @@ deterministic([],D,P,H,A) :-
     P == 0,
     D == 1,
     A =:= D+P+H,!.
-deterministic(_,D,P,H,A) :-
+deterministic(_,_,P,_,_) :-
     P > 1,
     !,fail.
-deterministic([(Head :- !)|Cs],D,P,H,A) :-
+deterministic([(_ :- !)|Cs],D,P,H,A) :-
     H1 is H+1,!,
     deterministic(Cs,D,P,H1,A).
 deterministic([(Head :- Body)|Cs],D,P,H,A) :-
-    det_body(Head,Body),
+    det_body(Head,Body,[]),
     D1 is D+1,!,
     deterministic(Cs,D1,P,H,A).
 deterministic([X|Cs],D,P,H,A) :-
     n_property(X,predicate),
     P1 is P+1,!,
     deterministic(Cs,D,P1,H,A).
-dterministic([C|Cs],D,P,H,A) :-
+deterministic([_|Cs],D,P,H,A) :-
     deterministic(Cs,D,P,H,A).
 
 % arguments = [clauses],tail_count,pred_count, halt_base_count,all_count, arity
-tail_recursive([],T,P,H,A,N) :-
-    %write(user_output,T),write(user_output,P),write(user_output,H),write(user_output,A),nl,
+tail_recursive([],T,P,H,A,_) :-
     T > 0,
     P == 0,
     H >= 1,
     A =:= T+P+H,!.
-tail_recursive(_,T,P,H,A,N) :-
+tail_recursive(_,_,P,_,_,_) :-
     P > 1,
     !,fail.
-tail_recursive([(Head :- !)|Cs],T,P,H,A,N) :-
+tail_recursive([(_ :- !)|Cs],T,P,H,A,N) :-
     H1 is H+1,!,
     tail_recursive(Cs,T,P,H1,A,N).
 tail_recursive([(Head :- Body)|Cs],T,P,H,A,N) :-
     independ(Head),
     butlast_body(Body,Body1),
-    det_body(Head,Body1),
+    det_body(Head,Body1,[]),
     tail_body(Head,Body),
     not(tail_body(Head,Body1)), % ...,qsort(),qsort(). not tco
     T1 is T+1,!,
@@ -1664,7 +1727,7 @@ tail_recursive([X|Cs],D,P,H,A,N) :-
     n_property(X,predicate),
     P1 is P+1,!,
     tail_recursive(Cs,D,P1,H,A,N).
-tail_recursive([C|Cs],D,P,H,A,N) :-
+tail_recursive([_|Cs],D,P,H,A,N) :-
     tail_recursive(Cs,D,P,H,A,N).
 
 independ(Head) :-
@@ -1680,22 +1743,22 @@ independ1([X|Xs]) :-
     flatten(Xs,F),
     independ2(X,F),
     independ1(Xs).
-independ1([X|Xs]) :-
+independ1([_|Xs]) :-
     independ1(Xs).
-independ1(X).        
+independ1(_).        
     
-independ2([],F).
-independ2([X|Xs],F) :-
+independ2([],_).
+independ2([X|_],F) :-
     n_compiler_variable(X),
     member(X,F),
     !,fail.
-independ2([X|Xs],F) :-
+independ2([_|Xs],F) :-
     independ2(Xs,F).
 independ2(X,F) :-
     n_compiler_variable(X),
     member(X,F),
     !,fail.
-independ2(X,F) :-
+independ2(X,_) :-
     atomic(X).
             
                 
@@ -1714,17 +1777,17 @@ flatten([L|Ls],Z) :-
             
     
 % arguments = [clauses],det_count,pred_count,all_count
-halt_check([],H,P,A) :-
+halt_check([],H,P,_) :-
     %write(user_output,H),write(user_output,P),write(user_output,A),
     P == 0,
     H == 1,!.
-halt_check(_,H,P,A) :-
+halt_check(_,_,P,_) :-
     P > 1,
     !,fail.
-halt_check([(Head :- !)|Cs],H,P,A) :-
+halt_check([(_ :- !)|Cs],H,P,A) :-
     H1 is H+1,!,
     halt_check(Cs,H1,P,A).
-halt_check([(Head :- Body)|Cs],H,P,A) :-
+halt_check([(_ :- _)|Cs],H,P,A) :-
     halt_check(Cs,H,P,A).
 halt_check([X|Cs],H,P,A) :-
     X =.. [_|Args],
@@ -1735,44 +1798,47 @@ halt_check([X|Cs],D,P,A) :-
     n_property(X,predicate),
     P1 is P+1,!,
     halt_check(Cs,D,P1,A).
-halt_check([C|Cs],D,P,A) :-
+halt_check([_|Cs],D,P,A) :-
     halt_check(Cs,D,P,A).
 
 
 
 % deterministic body case. Each has cut or each is builtin or each is recur 
-det_body(Head,(X;Y)) :- fail.
-det_body(Head,!).
-det_body(Head,(X,!)).
-det_body(Head,(X,(!,Y))) :-
-    det_body(Head,Y).
-det_body(Head,(X,Y)) :-
-    det_builtin(X),
-    det_body(Head,Y).
-det_body(Head,(X,Y)) :-
+% G is gournd_variable
+det_body(_,(_;_),_) :- fail.
+det_body(_,!,_).
+det_body(_,(_,!),_).
+det_body(Head,(_,(!,Y)),G) :-
+    det_body(Head,Y,G).
+det_body(Head,(V is _,Y),G) :-
+    det_body(Head,Y,[V|G]).
+det_body(Head,(X,Y),G) :-
+    det_builtin(X,G),
+    det_body(Head,Y,G).
+det_body(Head,(X,Y),G) :-
     det_pass1(X),
-    det_body(Head,Y).
-det_body(Head,(X,Y)) :-
+    det_body(Head,Y,G).
+det_body(Head,(X,Y),G) :-
     functor(Head,Pred1,Arity1),
     functor(X,Pred2,Arity2),
     Pred1 == Pred2,
     Arity1 == Arity2,
     pred_data(Pred1,Arity1,halt),
-    P =.. [pred_data,Pred1,A1,A2],
+    P =.. [pred_data,Pred1,_,_],
     (retract(P);true),
     asserta(pred_data(Pred1,Arity1,det)),
-    det_body(Head,Y).
-det_body(Head,X) :-
-    det_builtin(X).
-det_body(Head,X) :-
+    det_body(Head,Y,G).
+det_body(_,X,G) :-
+    det_builtin(X,G).
+det_body(_,X,_) :-
     det_pass1(X).
-det_body(Head,X) :-
+det_body(Head,X,_) :-
     functor(Head,Pred1,Arity1),
     functor(X,Pred2,Arity2),
     Pred1 == Pred2,
     Arity1 == Arity2,
     pred_data(Pred1,Arity1,halt),
-    P =.. [pred_data,Pred1,A1,A2],
+    P =.. [pred_data,Pred1,_,_],
     (retract(P);true),
     asserta(pred_data(Pred1,Arity1,det)).
 det_pass1(X) :-
@@ -1784,15 +1850,23 @@ det_pass1(X) :-
 
 
 % generaly builtin is deterministic. but some cases is non deterministic.
-det_builtin(length(X,Y)) :-
+det_builtin(length(X,Y),G) :-
     n_compiler_variable(X),
-    n_compiler_variable(Y),!,fail.
+    not(member(X,G)),
+    n_compiler_variable(Y),
+    not(member(Y,G)),!,fail.
 
-det_builtin(append(X,Y,_)) :-
+det_builtin(append(X,Y,_),G) :-
     n_compiler_variable(X),
-    n_compiler_variable(Y),!,fail.
+    not(member(X,G)),
+    n_compiler_variable(Y),
+    not(member(Y,G)),!,fail.
 
-det_builtin(X) :-
+det_builtin(member(_,X),G) :-
+    n_compiler_variable(X),
+    not(member(X,G)),!,fail.
+
+det_builtin(X,_) :-
     n_property(X,builtin).
 
 
@@ -1842,7 +1916,7 @@ gen_tail_body(X,N) :-
     write('goto loop'),write(N),write(';'),nl,
     write('}'),nl.
 
-gen_tail_args([],N).
+gen_tail_args([],_).
 gen_tail_args([A|As],N) :-
     write('arg'),write(N),write(' = '),
     write('Jcopy_work(Jderef('),
@@ -2075,7 +2149,7 @@ eval_form(X /\ Y) :-
     eval_form(Y),
     write(',th)').
 eval_form(X \/ Y) :-
-	  write('Jlogicalor('),
+	write('Jlogicalor('),
     eval_form(X),
     write(','),
     eval_form(Y),
