@@ -17,7 +17,7 @@ address
  5,000,001 - 30,000,000  working area 
 30,000,001 - 32,000,000  variant area
 */
-#define VERSION     4.50
+#define VERSION     4.55
 #define CELLSIZE    30000000  // if raspberry PI set smaller size.
 #define HEAPSIZE     5000000
 #define FREESIZE         500
@@ -558,6 +558,7 @@ extern int active_thread;
 extern int dynamic_flag;
 extern int string_flag;
 extern int ifthenelse_false_flag;
+extern int compiled_flag;
 
 //------pointer----
 extern int hp; 
@@ -756,7 +757,7 @@ int bcons(int car, int cdr);
 int b_abolish(int arglist, int rest, int th);
 int b_abort(int arglist, int rest, int th);
 int b_add_curl_header(int arglist, int rest, int th);
-int b_after_cut(int arglist, int rest, int th);
+int b_n_after_cut(int arglist, int rest, int th);
 int b_ansi_cup(int arglist, int rest, int th);
 int b_ansi_cuu(int arglist, int rest, int th);
 int b_ansi_cud(int arglist, int rest, int th);
@@ -771,16 +772,15 @@ int b_ansi_el(int arglist, int rest, int th);
 int b_append(int arglist, int rest, int th);
 int b_arg(int arglist, int rest, int th);
 int b_arg0(int arglist, int rest, int th);
-int b_arity_count(int arglist, int rest, int th);
-int b_ask(int arglist, int rest, int th);
+int b_n_arity_count(int arglist, int rest, int th);
+int b_n_ask(int arglist, int rest, int th);
 int b_assert(int arglist, int rest, int th);
 int b_asserta(int arglist, int rest, int th);
 int b_assertz(int arglist, int rest, int th);
-int b_ateqsmaller(int arglist, int rest, int th);
-int b_atsmaller(int arglist, int rest, int th);
-int b_atgreater(int arglist, int rest, int th);
-int b_ateqgreater(int arglist, int rest, int th);
-int b_atmark(int arglist, int rest, int th);
+int b_n_ateqsmaller(int arglist, int rest, int th);
+int b_n_atsmaller(int arglist, int rest, int th);
+int b_n_atgreater(int arglist, int rest, int th);
+int b_n_ateqgreater(int arglist, int rest, int th);
 int b_atom(int arglist, int rest, int th);
 int b_atom_string(int arglist, int rest, int th);
 int b_atom_concat(int arglist, int rest, int th);
@@ -788,14 +788,14 @@ int b_atom_length(int arglist, int rest, int th);
 int b_atom_codes(int arglist, int rest, int th);
 int b_atom_chars(int arglist, int rest, int th);
 int b_atomic(int arglist, int rest, int th);
-int b_atom_convert(int arglist, int rest, int th);
-int b_atsmaller(int arglist, int rest, int th);
+int b_n_atom_convert(int arglist, int rest, int th);
+int b_n_atsmaller(int arglist, int rest, int th);
 int b_at_end_of_stream(int arglist, int rest, int th);
-int b_before_cut(int arglist, int rest, int th);
+int b_n_before_cut(int arglist, int rest, int th);
 int b_bagof(int arglist, int rest, int th);
 int b_bagofhelper(int arglist, int rest, int th);
 int b_between(int arglist, int rest, int th);
-int b_bignum(int arglist, int rest, int th);
+int b_n_bignum(int arglist, int rest, int th);
 int b_break(int arglist, int rest, int th);
 int b_call(int arglist, int rest, int th);
 int b_catch(int arglist, int rest, int th);
@@ -805,14 +805,14 @@ int b_char_conversion(int arglist, int rest, int th);
 int b_char_set(int arglist, int rest, int th);
 int b_cinline(int arglist, int rest, int th);
 int b_clause(int arglist, int rest, int th);
-int b_clause_with_arity(int arglist, int rest, int th);
+int b_n_clause_with_arity(int arglist, int rest, int th);
 int b_create_client_socket(int arglist, int rest, int th);
 int b_close(int arglist, int rest, int th);
 int b_close_curl(int arglist, int rest, int th);
 int b_close_socket(int arglist, int rest, int th);
 int b_compare(int arglist, int rest, int th);
-int b_compiler_anonymous(int arglist, int rest, int th);
-int b_compiler_variable(int arglist, int rest, int th);
+int b_n_compiler_anonymous(int arglist, int rest, int th);
+int b_n_compiler_variable(int arglist, int rest, int th);
 int b_compound(int arglist, int rest, int th);
 int b_concat(int arglist, int rest, int th);
 int b_consult(int arglist, int rest, int th);
@@ -830,13 +830,13 @@ int b_current_input(int arglist, int rest, int th);
 int b_current_output(int arglist, int rest, int th);
 int b_current_op(int arglist, int rest, int th);
 int b_current_predicate(int arglist, int rest, int th);
-int b_cut(int arglist, int rest, int th);
+int b_n_cut(int arglist, int rest, int th);
 int b_date_day(int arglist, int rest, int th);
 int b_date(int arglist, int rest, int th);
 int b_dec(int arglist, int rest, int th);
 int b_debug(int arglist, int rest, int th);
-int b_defined_predicate(int arglist, int rest, int th);
-int b_defined_userop(int arglist, int rest, int th);
+int b_n_defined_predicate(int arglist, int rest, int th);
+int b_n_defined_userop(int arglist, int rest, int th);
 int b_delete(int arglist, int rest, int th);
 int b_directory(int arglist, int rest, int th);
 int b_display(int arglist, int rest, int th);
@@ -858,41 +858,48 @@ int b_dp_pause(int arglist, int rest, int th);
 int b_dp_resume(int arglist, int rest, int th);
 int b_dup(int arglist, int rest, int th);
 int b_dynamic(int arglist, int rest, int th);
-int b_dynamic_predicate(int arglist, int rest, int th);
+int b_n_dynamic_predicate(int arglist, int rest, int th);
 int b_edit(int arglist, int rest, int th);
 int b_end_of_file(int arglist, int rest, int th);
 int b_eq(int arglist, int rest, int th);
-int b_eqgreater(int arglist, int rest, int th);
-int b_eqsmaller(int arglist, int rest, int th);
-int b_equalp(int arglist, int rest, int th);
+int b_n_eqgreater(int arglist, int rest, int th);
+int b_n_eqsmaller(int arglist, int rest, int th);
+int b_n_equalp(int arglist, int rest, int th);
 int b_erase(int arglist, int rest, int th);
 int b_eraseall(int arglist, int rest, int th);
 int b_errcode(int arglist, int rest, int th);
-int b_error(int arglist, int rest, int th);
+int b_n_error(int arglist, int rest, int th);
 int b_existerrors(int arglist, int rest, int th);
+int b_n_exec_is(int arglist, int rest, int th);
+int b_n_exec_smaller(int arglist, int rest, int th);
+int b_n_exec_greater(int arglist, int rest, int th);
+int b_n_exec_eqsmaller(int arglist, int rest, int th);
+int b_n_exec_eqgreater(int arglist, int rest, int th);
 int b_fail(int arglist, int rest, int th);
 int b_findall(int arglist, int rest, int th);
-int b_findatom(int arglist, int rest, int th);
+int b_n_findatom(int arglist, int rest, int th);
 int b_fileerrors(int arglist, int rest, int th);
-int b_filename(int arglist, int rest, int th);
+int b_n_filename(int arglist, int rest, int th);
 int b_float_text(int arglist, int rest, int th);
 int b_flush(int arglist, int rest, int th);
 int b_flush_output(int arglist, int rest, int th);
 int b_format(int arglist, int rest, int th);
 int b_functor(int arglist, int rest, int th);
 int b_gbc(int arglist, int rest, int th);
-int b_generate_all_variable(int arglist, int rest, int th);
-int b_generate_variable(int arglist, int rest, int th);
+int b_n_generate_all_variable(int arglist, int rest, int th);
+int b_n_generate_variable(int arglist, int rest, int th);
 int b_get(int arglist, int rest, int th);
 int b_get0(int arglist, int rest, int th);
 int b_get0_noecho(int arglist, int rest, int th);
 int b_get_byte(int arglist, int rest, int th);
 int b_get_char(int arglist, int rest, int th);
 int b_get_code(int arglist, int rest, int th);
-int b_greater(int arglist, int rest, int th);
+int b_n_get_dynamic(int arglist, int rest, int th);
+int b_n_get_execute(int arglist, int rest, int th);
+int b_n_greater(int arglist, int rest, int th);
 int b_ground(int arglist, int rest, int th);
 int b_halt(int arglist, int rest, int th);
-int b_has_cut(int arglist, int rest, int th);
+int b_n_has_cut(int arglist, int rest, int th);
 int b_heapdump(int arglist, int rest, int th);
 int b_inc(int arglist, int rest, int th);
 int b_initialization(int arglist, int rest, int th);
@@ -909,7 +916,7 @@ int b_length(int arglist, int rest, int th);
 int b_list(int arglist, int rest, int th);
 int b_listing(int arglist, int rest, int th);
 int b_list_text(int arglist, int rest, int th);
-int b_longnum(int arglist, int rest, int th);
+int b_n_longnum(int arglist, int rest, int th);
 int b_mkdir(int arglist, int rest, int th);
 int b_member(int arglist, int rest, int th);
 int b_measure(int arglist, int rest, int th);
@@ -924,30 +931,30 @@ int b_nl(int arglist, int rest, int th);
 int b_nonvar(int arglist, int rest, int th);
 int b_nospy(int arglist, int rest, int th);
 int b_not(int arglist, int rest, int th);
-int b_notequalp(int arglist, int rest, int th);
-int b_notnumeq(int arglist, int rest, int th);
+int b_n_notequalp(int arglist, int rest, int th);
+int b_n_notnumeq(int arglist, int rest, int th);
 int b_notrace(int arglist, int rest, int th);
-int b_notunify(int arglist, int rest, int th);
+int b_n_notunify(int arglist, int rest, int th);
 int b_name(int arglist, int rest, int th);
 int b_number(int arglist, int rest, int th);
 int b_number_chars(int arglist, int rest, int th);
 int b_number_codes(int arglist, int rest, int th);
 int b_numbervars(int arglist, int rest, int th);
-int b_numeq(int arglist, int rest, int th);
+int b_n_numeq(int arglist, int rest, int th);
 int b_nth_char(int arglist, int rest, int th);
 int b_nref(int arglist, int rest, int th);
 int b_nth_ref(int arglist, int rest, int th);
 int b_once(int arglist, int rest, int th);
 int b_op(int arglist, int rest, int th);
 int b_open(int arglist, int rest, int th);
-int b_pair_list(int arglist, int rest, int th);
+int b_n_pair_list(int arglist, int rest, int th);
 int b_peek_byte(int arglist, int rest, int th);
 int b_peek_char(int arglist, int rest, int th);
 int b_peek_code(int arglist, int rest, int th);
 int b_peek_byte(int arglist, int rest, int th);
 int b_predicate_property(int arglist, int rest, int th);
 int b_pref(int arglist, int rest, int th);
-int b_property(int arglist, int rest, int th);
+int b_n_property(int arglist, int rest, int th);
 int b_put(int arglist, int rest, int th);
 int b_put_char(int arglist, int rest, int th);
 int b_put_code(int arglist, int rest, int th);
@@ -970,8 +977,8 @@ int b_retract(int arglist, int rest, int th);
 int b_retrieveh(int arglist, int rest, int th);
 int b_recv_curl(int arglist, int rest, int th);
 int b_recv_socket(int arglist, int rest, int th);
-int b_reconsult_predicate(int arglist, int rest, int th);
-int b_reconsult_abolish(int arglist, int rest, int th);
+int b_n_reconsult_predicate(int arglist, int rest, int th);
+int b_n_reconsult_abolish(int arglist, int rest, int th);
 int b_rmdir(int arglist, int rest, int th);
 int b_removeh(int arglist, int rest, int th);
 int b_removeallh(int arglist, int rest, int th);
@@ -990,7 +997,7 @@ int b_set_output(int arglist, int rest, int th);
 int b_set_prolog_flag(int arglist, int rest, int th);
 int b_shell(int arglist, int rest, int th);
 int b_skip(int arglist, int rest, int th);
-int b_smaller(int arglist, int rest, int th);
+int b_n_smaller(int arglist, int rest, int th);
 int b_sort(int arglist, int rest, int th);
 int b_spy(int arglist, int rest, int th);
 int b_statistics(int arglist, int rest, int th);
@@ -1015,11 +1022,11 @@ int b_time(int arglist, int rest, int th);
 int b_told(int arglist, int rest, int th);
 int b_trace(int arglist, int rest, int th);
 int b_true(int arglist, int rest, int th);
-int b_unify(int arglist, int rest, int th);
-int b_univ(int arglist, int rest, int th);
+int b_n_unify(int arglist, int rest, int th);
+int b_n_univ(int arglist, int rest, int th);
 int b_use_module(int arglist, int rest, int th);
 int b_var(int arglist, int rest, int th);
-int b_variable_convert(int arglist, int rest, int th);
+int b_n_variable_convert(int arglist, int rest, int th);
 int b_unify_with_occurs_check(int arglist, int rest, int th);
 int b_write(int arglist, int rest, int th);
 int b_writeq(int arglist, int rest, int th);
@@ -1510,10 +1517,6 @@ void unreadc(char c);
 char *prolog_file_name(char *name);
 
 //JUMP project
-int b_dynamic_check(int arglist, int rest, int th);
-int b_get_dynamic(int arglist, int rest, int th);
-int b_get_execute(int arglist, int rest, int th);
-int b_write_original_variable(int arglist, int n);
 int dynamic_check1(int x);
 int get_tag(int addr);
 int get_int(int addr);
